# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto',
  package='k8s.io.apimachinery.pkg.apis.meta.v1',
  syntax='proto2',
  serialized_options=b'Z\002v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x12$k8s.io.apimachinery.pkg.apis.meta.v1\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"\xa9\x02\n\x08\x41PIGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12P\n\x08versions\x18\x02 \x03(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12X\n\x10preferredVersion\x18\x03 \x01(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12\x63\n\x1aserverAddressByClientCIDRs\x18\x04 \x03(\x0b\x32?.k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\"N\n\x0c\x41PIGroupList\x12>\n\x06groups\x18\x01 \x03(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup\"\xf3\x01\n\x0b\x41PIResource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0csingularName\x18\x06 \x01(\t\x12\x12\n\nnamespaced\x18\x02 \x01(\x08\x12\r\n\x05group\x18\x08 \x01(\t\x12\x0f\n\x07version\x18\t \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12:\n\x05verbs\x18\x04 \x01(\x0b\x32+.k8s.io.apimachinery.pkg.apis.meta.v1.Verbs\x12\x12\n\nshortNames\x18\x05 \x03(\t\x12\x12\n\ncategories\x18\x07 \x03(\t\x12\x1a\n\x12storageVersionHash\x18\n \x01(\t\"m\n\x0f\x41PIResourceList\x12\x14\n\x0cgroupVersion\x18\x01 \x01(\t\x12\x44\n\tresources\x18\x02 \x03(\x0b\x32\x31.k8s.io.apimachinery.pkg.apis.meta.v1.APIResource\"\x84\x01\n\x0b\x41PIVersions\x12\x10\n\x08versions\x18\x01 \x03(\t\x12\x63\n\x1aserverAddressByClientCIDRs\x18\x02 \x03(\x0b\x32?.k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\"C\n\x0c\x41pplyOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\"\xae\x01\n\tCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"5\n\rCreateOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\"\xbc\x01\n\rDeleteOptions\x12\x1a\n\x12gracePeriodSeconds\x18\x01 \x01(\x03\x12J\n\rpreconditions\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions\x12\x18\n\x10orphanDependents\x18\x03 \x01(\x08\x12\x19\n\x11propagationPolicy\x18\x04 \x01(\t\x12\x0e\n\x06\x64ryRun\x18\x05 \x03(\t\"\x1c\n\x08\x44uration\x12\x10\n\x08\x64uration\x18\x01 \x01(\x03\"\x17\n\x08\x46ieldsV1\x12\x0b\n\x03Raw\x18\x01 \x01(\x0c\"%\n\nGetOptions\x12\x17\n\x0fresourceVersion\x18\x01 \x01(\t\"(\n\tGroupKind\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\"0\n\rGroupResource\x12\r\n\x05group\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\".\n\x0cGroupVersion\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"A\n\x18GroupVersionForDiscovery\x12\x14\n\x0cgroupVersion\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"@\n\x10GroupVersionKind\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\"H\n\x14GroupVersionResource\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\"\xf8\x01\n\rLabelSelector\x12Y\n\x0bmatchLabels\x18\x01 \x03(\x0b\x32\x44.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry\x12X\n\x10matchExpressions\x18\x02 \x03(\x0b\x32>.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement\x1a\x32\n\x10MatchLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x18LabelSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x86\x01\n\x04List\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12<\n\x05items\x18\x02 \x03(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtension\"c\n\x08ListMeta\x12\x10\n\x08selfLink\x18\x01 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x02 \x01(\t\x12\x10\n\x08\x63ontinue\x18\x03 \x01(\t\x12\x1a\n\x12remainingItemCount\x18\x04 \x01(\x03\"\xd7\x01\n\x0bListOptions\x12\x15\n\rlabelSelector\x18\x01 \x01(\t\x12\x15\n\rfieldSelector\x18\x02 \x01(\t\x12\r\n\x05watch\x18\x03 \x01(\x08\x12\x1b\n\x13\x61llowWatchBookmarks\x18\t \x01(\x08\x12\x17\n\x0fresourceVersion\x18\x04 \x01(\t\x12\x1c\n\x14resourceVersionMatch\x18\n \x01(\t\x12\x16\n\x0etimeoutSeconds\x18\x05 \x01(\x03\x12\r\n\x05limit\x18\x07 \x01(\x03\x12\x10\n\x08\x63ontinue\x18\x08 \x01(\t\"\xdc\x01\n\x12ManagedFieldsEntry\x12\x0f\n\x07manager\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x12\n\napiVersion\x18\x03 \x01(\t\x12\x38\n\x04time\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nfieldsType\x18\x06 \x01(\t\x12@\n\x08\x66ieldsV1\x18\x07 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1\"+\n\tMicroTime\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"\x93\x06\n\nObjectMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cgenerateName\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x10\n\x08selfLink\x18\x04 \x01(\t\x12\x0b\n\x03uid\x18\x05 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x06 \x01(\t\x12\x12\n\ngeneration\x18\x07 \x01(\x03\x12\x45\n\x11\x63reationTimestamp\x18\x08 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x45\n\x11\x64\x65letionTimestamp\x18\t \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\"\n\x1a\x64\x65letionGracePeriodSeconds\x18\n \x01(\x03\x12L\n\x06labels\x18\x0b \x03(\x0b\x32<.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry\x12V\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32\x41.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry\x12M\n\x0fownerReferences\x18\r \x03(\x0b\x32\x34.k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference\x12\x12\n\nfinalizers\x18\x0e \x03(\t\x12\x13\n\x0b\x63lusterName\x18\x0f \x01(\t\x12O\n\rmanagedFields\x18\x11 \x03(\x0b\x32\x38.k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x0eOwnerReference\x12\x12\n\napiVersion\x18\x05 \x01(\t\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x12\n\ncontroller\x18\x06 \x01(\x08\x12\x1a\n\x12\x62lockOwnerDeletion\x18\x07 \x01(\x08\"[\n\x15PartialObjectMetadata\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\"\xa9\x01\n\x19PartialObjectMetadataList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12J\n\x05items\x18\x02 \x03(\x0b\x32;.k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata\"\x07\n\x05Patch\"C\n\x0cPatchOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x14\n\x0c\x66ieldManager\x18\x03 \x01(\t\"5\n\rPreconditions\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x02 \x01(\t\"\x1a\n\tRootPaths\x12\r\n\x05paths\x18\x01 \x03(\t\"F\n\x19ServerAddressByClientCIDR\x12\x12\n\nclientCIDR\x18\x01 \x01(\t\x12\x15\n\rserverAddress\x18\x02 \x01(\t\"\xcf\x01\n\x06Status\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x44\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails\x12\x0c\n\x04\x63ode\x18\x06 \x01(\x05\"=\n\x0bStatusCause\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x66ield\x18\x03 \x01(\t\"\xa5\x01\n\rStatusDetails\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x41\n\x06\x63\x61uses\x18\x04 \x03(\x0b\x32\x31.k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause\x12\x19\n\x11retryAfterSeconds\x18\x05 \x01(\x05\"%\n\x0cTableOptions\x12\x15\n\rincludeObject\x18\x01 \x01(\t\"&\n\x04Time\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"+\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\",\n\x08TypeMeta\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x12\n\napiVersion\x18\x02 \x01(\t\"5\n\rUpdateOptions\x12\x0e\n\x06\x64ryRun\x18\x01 \x03(\t\x12\x14\n\x0c\x66ieldManager\x18\x02 \x01(\t\"\x16\n\x05Verbs\x12\r\n\x05items\x18\x01 \x03(\t\"Y\n\nWatchEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12=\n\x06object\x18\x02 \x01(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtensionB\x04Z\x02v1'
  ,
  dependencies=[k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2.DESCRIPTOR,])




_APIGROUP = _descriptor.Descriptor(
  name='APIGroup',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup.versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferredVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup.preferredVersion', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverAddressByClientCIDRs', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup.serverAddressByClientCIDRs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=497,
)


_APIGROUPLIST = _descriptor.Descriptor(
  name='APIGroupList',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroupList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIGroupList.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=577,
)


_APIRESOURCE = _descriptor.Descriptor(
  name='APIResource',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singularName', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.singularName', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespaced', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.namespaced', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.group', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.version', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.kind', index=5,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbs', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.verbs', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortNames', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.shortNames', index=7,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categories', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.categories', index=8,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageVersionHash', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResource.storageVersionHash', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=823,
)


_APIRESOURCELIST = _descriptor.Descriptor(
  name='APIResourceList',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResourceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResourceList.groupVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIResourceList.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=934,
)


_APIVERSIONS = _descriptor.Descriptor(
  name='APIVersions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIVersions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIVersions.versions', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverAddressByClientCIDRs', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.APIVersions.serverAddressByClientCIDRs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1069,
)


_APPLYOPTIONS = _descriptor.Descriptor(
  name='ApplyOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions.dryRun', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldManager', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions.fieldManager', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1138,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.observedGeneration', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.lastTransitionTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Condition.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1141,
  serialized_end=1315,
)


_CREATEOPTIONS = _descriptor.Descriptor(
  name='CreateOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.CreateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.CreateOptions.dryRun', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldManager', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.CreateOptions.fieldManager', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1317,
  serialized_end=1370,
)


_DELETEOPTIONS = _descriptor.Descriptor(
  name='DeleteOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gracePeriodSeconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions.gracePeriodSeconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preconditions', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions.preconditions', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orphanDependents', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions.orphanDependents', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagationPolicy', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions.propagationPolicy', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions.dryRun', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1373,
  serialized_end=1561,
)


_DURATION = _descriptor.Descriptor(
  name='Duration',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Duration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Duration.duration', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1563,
  serialized_end=1591,
)


_FIELDSV1 = _descriptor.Descriptor(
  name='FieldsV1',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Raw', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1.Raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1593,
  serialized_end=1616,
)


_GETOPTIONS = _descriptor.Descriptor(
  name='GetOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GetOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GetOptions.resourceVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=1655,
)


_GROUPKIND = _descriptor.Descriptor(
  name='GroupKind',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupKind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupKind.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupKind.kind', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1657,
  serialized_end=1697,
)


_GROUPRESOURCE = _descriptor.Descriptor(
  name='GroupResource',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupResource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupResource.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupResource.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1699,
  serialized_end=1747,
)


_GROUPVERSION = _descriptor.Descriptor(
  name='GroupVersion',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersion.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersion.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1749,
  serialized_end=1795,
)


_GROUPVERSIONFORDISCOVERY = _descriptor.Descriptor(
  name='GroupVersionForDiscovery',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery.groupVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1862,
)


_GROUPVERSIONKIND = _descriptor.Descriptor(
  name='GroupVersionKind',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind.kind', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1864,
  serialized_end=1928,
)


_GROUPVERSIONRESOURCE = _descriptor.Descriptor(
  name='GroupVersionResource',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource.resource', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2002,
)


_LABELSELECTOR_MATCHLABELSENTRY = _descriptor.Descriptor(
  name='MatchLabelsEntry',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2253,
)

_LABELSELECTOR = _descriptor.Descriptor(
  name='LabelSelector',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchLabels', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.matchLabels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchExpressions', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.matchExpressions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LABELSELECTOR_MATCHLABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2253,
)


_LABELSELECTORREQUIREMENT = _descriptor.Descriptor(
  name='LabelSelectorRequirement',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement.operator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2255,
  serialized_end=2328,
)


_LIST = _descriptor.Descriptor(
  name='List',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.List.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.List.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2465,
)


_LISTMETA = _descriptor.Descriptor(
  name='ListMeta',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selfLink', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta.selfLink', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta.resourceVersion', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta.continue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remainingItemCount', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta.remainingItemCount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2467,
  serialized_end=2566,
)


_LISTOPTIONS = _descriptor.Descriptor(
  name='ListOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labelSelector', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.labelSelector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldSelector', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.fieldSelector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watch', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.watch', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowWatchBookmarks', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.allowWatchBookmarks', index=3,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.resourceVersion', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersionMatch', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.resourceVersionMatch', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeoutSeconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.timeoutSeconds', index=6,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.limit', index=7,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions.continue', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2569,
  serialized_end=2784,
)


_MANAGEDFIELDSENTRY = _descriptor.Descriptor(
  name='ManagedFieldsEntry',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manager', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.manager', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.operation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apiVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.apiVersion', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldsType', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.fieldsType', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldsV1', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry.fieldsV1', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=3007,
)


_MICROTIME = _descriptor.Descriptor(
  name='MicroTime',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3009,
  serialized_end=3052,
)


_OBJECTMETA_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3745,
  serialized_end=3790,
)

_OBJECTMETA_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3792,
  serialized_end=3842,
)

_OBJECTMETA = _descriptor.Descriptor(
  name='ObjectMeta',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generateName', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.generateName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selfLink', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.selfLink', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.uid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.resourceVersion', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generation', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.generation', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creationTimestamp', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.creationTimestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletionTimestamp', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.deletionTimestamp', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletionGracePeriodSeconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.deletionGracePeriodSeconds', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.labels', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.annotations', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ownerReferences', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.ownerReferences', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finalizers', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.finalizers', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterName', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.clusterName', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managedFields', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.managedFields', index=15,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTMETA_LABELSENTRY, _OBJECTMETA_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3055,
  serialized_end=3842,
)


_OWNERREFERENCE = _descriptor.Descriptor(
  name='OwnerReference',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.apiVersion', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.kind', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.uid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controller', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.controller', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blockOwnerDeletion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference.blockOwnerDeletion', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3844,
  serialized_end=3969,
)


_PARTIALOBJECTMETADATA = _descriptor.Descriptor(
  name='PartialObjectMetadata',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3971,
  serialized_end=4062,
)


_PARTIALOBJECTMETADATALIST = _descriptor.Descriptor(
  name='PartialObjectMetadataList',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadataList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadataList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4065,
  serialized_end=4234,
)


_PATCH = _descriptor.Descriptor(
  name='Patch',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Patch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4236,
  serialized_end=4243,
)


_PATCHOPTIONS = _descriptor.Descriptor(
  name='PatchOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions.dryRun', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldManager', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions.fieldManager', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4245,
  serialized_end=4312,
)


_PRECONDITIONS = _descriptor.Descriptor(
  name='Preconditions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions.uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions.resourceVersion', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4314,
  serialized_end=4367,
)


_ROOTPATHS = _descriptor.Descriptor(
  name='RootPaths',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.RootPaths',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paths', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.RootPaths.paths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4369,
  serialized_end=4395,
)


_SERVERADDRESSBYCLIENTCIDR = _descriptor.Descriptor(
  name='ServerAddressByClientCIDR',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientCIDR', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR.clientCIDR', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serverAddress', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR.serverAddress', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4397,
  serialized_end=4467,
)


_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.details', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Status.code', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4470,
  serialized_end=4677,
)


_STATUSCAUSE = _descriptor.Descriptor(
  name='StatusCause',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause.reason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause.field', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4679,
  serialized_end=4740,
)


_STATUSDETAILS = _descriptor.Descriptor(
  name='StatusDetails',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.group', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.kind', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.uid', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='causes', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.causes', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retryAfterSeconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails.retryAfterSeconds', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4743,
  serialized_end=4908,
)


_TABLEOPTIONS = _descriptor.Descriptor(
  name='TableOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.TableOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='includeObject', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.TableOptions.includeObject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4910,
  serialized_end=4947,
)


_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Time.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Time.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4949,
  serialized_end=4987,
)


_TIMESTAMP = _descriptor.Descriptor(
  name='Timestamp',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Timestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Timestamp.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Timestamp.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4989,
  serialized_end=5032,
)


_TYPEMETA = _descriptor.Descriptor(
  name='TypeMeta',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.TypeMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.TypeMeta.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apiVersion', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.TypeMeta.apiVersion', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5034,
  serialized_end=5078,
)


_UPDATEOPTIONS = _descriptor.Descriptor(
  name='UpdateOptions',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.UpdateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.UpdateOptions.dryRun', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldManager', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.UpdateOptions.fieldManager', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5080,
  serialized_end=5133,
)


_VERBS = _descriptor.Descriptor(
  name='Verbs',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Verbs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.Verbs.items', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5135,
  serialized_end=5157,
)


_WATCHEVENT = _descriptor.Descriptor(
  name='WatchEvent',
  full_name='k8s.io.apimachinery.pkg.apis.meta.v1.WatchEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.WatchEvent.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='k8s.io.apimachinery.pkg.apis.meta.v1.WatchEvent.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5159,
  serialized_end=5248,
)

_APIGROUP.fields_by_name['versions'].message_type = _GROUPVERSIONFORDISCOVERY
_APIGROUP.fields_by_name['preferredVersion'].message_type = _GROUPVERSIONFORDISCOVERY
_APIGROUP.fields_by_name['serverAddressByClientCIDRs'].message_type = _SERVERADDRESSBYCLIENTCIDR
_APIGROUPLIST.fields_by_name['groups'].message_type = _APIGROUP
_APIRESOURCE.fields_by_name['verbs'].message_type = _VERBS
_APIRESOURCELIST.fields_by_name['resources'].message_type = _APIRESOURCE
_APIVERSIONS.fields_by_name['serverAddressByClientCIDRs'].message_type = _SERVERADDRESSBYCLIENTCIDR
_CONDITION.fields_by_name['lastTransitionTime'].message_type = _TIME
_DELETEOPTIONS.fields_by_name['preconditions'].message_type = _PRECONDITIONS
_LABELSELECTOR_MATCHLABELSENTRY.containing_type = _LABELSELECTOR
_LABELSELECTOR.fields_by_name['matchLabels'].message_type = _LABELSELECTOR_MATCHLABELSENTRY
_LABELSELECTOR.fields_by_name['matchExpressions'].message_type = _LABELSELECTORREQUIREMENT
_LIST.fields_by_name['metadata'].message_type = _LISTMETA
_LIST.fields_by_name['items'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2._RAWEXTENSION
_MANAGEDFIELDSENTRY.fields_by_name['time'].message_type = _TIME
_MANAGEDFIELDSENTRY.fields_by_name['fieldsV1'].message_type = _FIELDSV1
_OBJECTMETA_LABELSENTRY.containing_type = _OBJECTMETA
_OBJECTMETA_ANNOTATIONSENTRY.containing_type = _OBJECTMETA
_OBJECTMETA.fields_by_name['creationTimestamp'].message_type = _TIME
_OBJECTMETA.fields_by_name['deletionTimestamp'].message_type = _TIME
_OBJECTMETA.fields_by_name['labels'].message_type = _OBJECTMETA_LABELSENTRY
_OBJECTMETA.fields_by_name['annotations'].message_type = _OBJECTMETA_ANNOTATIONSENTRY
_OBJECTMETA.fields_by_name['ownerReferences'].message_type = _OWNERREFERENCE
_OBJECTMETA.fields_by_name['managedFields'].message_type = _MANAGEDFIELDSENTRY
_PARTIALOBJECTMETADATA.fields_by_name['metadata'].message_type = _OBJECTMETA
_PARTIALOBJECTMETADATALIST.fields_by_name['metadata'].message_type = _LISTMETA
_PARTIALOBJECTMETADATALIST.fields_by_name['items'].message_type = _PARTIALOBJECTMETADATA
_STATUS.fields_by_name['metadata'].message_type = _LISTMETA
_STATUS.fields_by_name['details'].message_type = _STATUSDETAILS
_STATUSDETAILS.fields_by_name['causes'].message_type = _STATUSCAUSE
_WATCHEVENT.fields_by_name['object'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2._RAWEXTENSION
DESCRIPTOR.message_types_by_name['APIGroup'] = _APIGROUP
DESCRIPTOR.message_types_by_name['APIGroupList'] = _APIGROUPLIST
DESCRIPTOR.message_types_by_name['APIResource'] = _APIRESOURCE
DESCRIPTOR.message_types_by_name['APIResourceList'] = _APIRESOURCELIST
DESCRIPTOR.message_types_by_name['APIVersions'] = _APIVERSIONS
DESCRIPTOR.message_types_by_name['ApplyOptions'] = _APPLYOPTIONS
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['CreateOptions'] = _CREATEOPTIONS
DESCRIPTOR.message_types_by_name['DeleteOptions'] = _DELETEOPTIONS
DESCRIPTOR.message_types_by_name['Duration'] = _DURATION
DESCRIPTOR.message_types_by_name['FieldsV1'] = _FIELDSV1
DESCRIPTOR.message_types_by_name['GetOptions'] = _GETOPTIONS
DESCRIPTOR.message_types_by_name['GroupKind'] = _GROUPKIND
DESCRIPTOR.message_types_by_name['GroupResource'] = _GROUPRESOURCE
DESCRIPTOR.message_types_by_name['GroupVersion'] = _GROUPVERSION
DESCRIPTOR.message_types_by_name['GroupVersionForDiscovery'] = _GROUPVERSIONFORDISCOVERY
DESCRIPTOR.message_types_by_name['GroupVersionKind'] = _GROUPVERSIONKIND
DESCRIPTOR.message_types_by_name['GroupVersionResource'] = _GROUPVERSIONRESOURCE
DESCRIPTOR.message_types_by_name['LabelSelector'] = _LABELSELECTOR
DESCRIPTOR.message_types_by_name['LabelSelectorRequirement'] = _LABELSELECTORREQUIREMENT
DESCRIPTOR.message_types_by_name['List'] = _LIST
DESCRIPTOR.message_types_by_name['ListMeta'] = _LISTMETA
DESCRIPTOR.message_types_by_name['ListOptions'] = _LISTOPTIONS
DESCRIPTOR.message_types_by_name['ManagedFieldsEntry'] = _MANAGEDFIELDSENTRY
DESCRIPTOR.message_types_by_name['MicroTime'] = _MICROTIME
DESCRIPTOR.message_types_by_name['ObjectMeta'] = _OBJECTMETA
DESCRIPTOR.message_types_by_name['OwnerReference'] = _OWNERREFERENCE
DESCRIPTOR.message_types_by_name['PartialObjectMetadata'] = _PARTIALOBJECTMETADATA
DESCRIPTOR.message_types_by_name['PartialObjectMetadataList'] = _PARTIALOBJECTMETADATALIST
DESCRIPTOR.message_types_by_name['Patch'] = _PATCH
DESCRIPTOR.message_types_by_name['PatchOptions'] = _PATCHOPTIONS
DESCRIPTOR.message_types_by_name['Preconditions'] = _PRECONDITIONS
DESCRIPTOR.message_types_by_name['RootPaths'] = _ROOTPATHS
DESCRIPTOR.message_types_by_name['ServerAddressByClientCIDR'] = _SERVERADDRESSBYCLIENTCIDR
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['StatusCause'] = _STATUSCAUSE
DESCRIPTOR.message_types_by_name['StatusDetails'] = _STATUSDETAILS
DESCRIPTOR.message_types_by_name['TableOptions'] = _TABLEOPTIONS
DESCRIPTOR.message_types_by_name['Time'] = _TIME
DESCRIPTOR.message_types_by_name['Timestamp'] = _TIMESTAMP
DESCRIPTOR.message_types_by_name['TypeMeta'] = _TYPEMETA
DESCRIPTOR.message_types_by_name['UpdateOptions'] = _UPDATEOPTIONS
DESCRIPTOR.message_types_by_name['Verbs'] = _VERBS
DESCRIPTOR.message_types_by_name['WatchEvent'] = _WATCHEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

APIGroup = _reflection.GeneratedProtocolMessageType('APIGroup', (_message.Message,), {
  'DESCRIPTOR' : _APIGROUP,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIGroup)
  })
_sym_db.RegisterMessage(APIGroup)

APIGroupList = _reflection.GeneratedProtocolMessageType('APIGroupList', (_message.Message,), {
  'DESCRIPTOR' : _APIGROUPLIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIGroupList)
  })
_sym_db.RegisterMessage(APIGroupList)

APIResource = _reflection.GeneratedProtocolMessageType('APIResource', (_message.Message,), {
  'DESCRIPTOR' : _APIRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIResource)
  })
_sym_db.RegisterMessage(APIResource)

APIResourceList = _reflection.GeneratedProtocolMessageType('APIResourceList', (_message.Message,), {
  'DESCRIPTOR' : _APIRESOURCELIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIResourceList)
  })
_sym_db.RegisterMessage(APIResourceList)

APIVersions = _reflection.GeneratedProtocolMessageType('APIVersions', (_message.Message,), {
  'DESCRIPTOR' : _APIVERSIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.APIVersions)
  })
_sym_db.RegisterMessage(APIVersions)

ApplyOptions = _reflection.GeneratedProtocolMessageType('ApplyOptions', (_message.Message,), {
  'DESCRIPTOR' : _APPLYOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ApplyOptions)
  })
_sym_db.RegisterMessage(ApplyOptions)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Condition)
  })
_sym_db.RegisterMessage(Condition)

CreateOptions = _reflection.GeneratedProtocolMessageType('CreateOptions', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.CreateOptions)
  })
_sym_db.RegisterMessage(CreateOptions)

DeleteOptions = _reflection.GeneratedProtocolMessageType('DeleteOptions', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.DeleteOptions)
  })
_sym_db.RegisterMessage(DeleteOptions)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Duration)
  })
_sym_db.RegisterMessage(Duration)

FieldsV1 = _reflection.GeneratedProtocolMessageType('FieldsV1', (_message.Message,), {
  'DESCRIPTOR' : _FIELDSV1,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.FieldsV1)
  })
_sym_db.RegisterMessage(FieldsV1)

GetOptions = _reflection.GeneratedProtocolMessageType('GetOptions', (_message.Message,), {
  'DESCRIPTOR' : _GETOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GetOptions)
  })
_sym_db.RegisterMessage(GetOptions)

GroupKind = _reflection.GeneratedProtocolMessageType('GroupKind', (_message.Message,), {
  'DESCRIPTOR' : _GROUPKIND,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupKind)
  })
_sym_db.RegisterMessage(GroupKind)

GroupResource = _reflection.GeneratedProtocolMessageType('GroupResource', (_message.Message,), {
  'DESCRIPTOR' : _GROUPRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupResource)
  })
_sym_db.RegisterMessage(GroupResource)

GroupVersion = _reflection.GeneratedProtocolMessageType('GroupVersion', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSION,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersion)
  })
_sym_db.RegisterMessage(GroupVersion)

GroupVersionForDiscovery = _reflection.GeneratedProtocolMessageType('GroupVersionForDiscovery', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONFORDISCOVERY,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery)
  })
_sym_db.RegisterMessage(GroupVersionForDiscovery)

GroupVersionKind = _reflection.GeneratedProtocolMessageType('GroupVersionKind', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONKIND,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionKind)
  })
_sym_db.RegisterMessage(GroupVersionKind)

GroupVersionResource = _reflection.GeneratedProtocolMessageType('GroupVersionResource', (_message.Message,), {
  'DESCRIPTOR' : _GROUPVERSIONRESOURCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.GroupVersionResource)
  })
_sym_db.RegisterMessage(GroupVersionResource)

LabelSelector = _reflection.GeneratedProtocolMessageType('LabelSelector', (_message.Message,), {

  'MatchLabelsEntry' : _reflection.GeneratedProtocolMessageType('MatchLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LABELSELECTOR_MATCHLABELSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LABELSELECTOR,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector)
  })
_sym_db.RegisterMessage(LabelSelector)
_sym_db.RegisterMessage(LabelSelector.MatchLabelsEntry)

LabelSelectorRequirement = _reflection.GeneratedProtocolMessageType('LabelSelectorRequirement', (_message.Message,), {
  'DESCRIPTOR' : _LABELSELECTORREQUIREMENT,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement)
  })
_sym_db.RegisterMessage(LabelSelectorRequirement)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
  'DESCRIPTOR' : _LIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.List)
  })
_sym_db.RegisterMessage(List)

ListMeta = _reflection.GeneratedProtocolMessageType('ListMeta', (_message.Message,), {
  'DESCRIPTOR' : _LISTMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta)
  })
_sym_db.RegisterMessage(ListMeta)

ListOptions = _reflection.GeneratedProtocolMessageType('ListOptions', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ListOptions)
  })
_sym_db.RegisterMessage(ListOptions)

ManagedFieldsEntry = _reflection.GeneratedProtocolMessageType('ManagedFieldsEntry', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDFIELDSENTRY,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry)
  })
_sym_db.RegisterMessage(ManagedFieldsEntry)

MicroTime = _reflection.GeneratedProtocolMessageType('MicroTime', (_message.Message,), {
  'DESCRIPTOR' : _MICROTIME,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime)
  })
_sym_db.RegisterMessage(MicroTime)

ObjectMeta = _reflection.GeneratedProtocolMessageType('ObjectMeta', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTMETA_LABELSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTMETA_ANNOTATIONSENTRY,
    '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta)
  })
_sym_db.RegisterMessage(ObjectMeta)
_sym_db.RegisterMessage(ObjectMeta.LabelsEntry)
_sym_db.RegisterMessage(ObjectMeta.AnnotationsEntry)

OwnerReference = _reflection.GeneratedProtocolMessageType('OwnerReference', (_message.Message,), {
  'DESCRIPTOR' : _OWNERREFERENCE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference)
  })
_sym_db.RegisterMessage(OwnerReference)

PartialObjectMetadata = _reflection.GeneratedProtocolMessageType('PartialObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PARTIALOBJECTMETADATA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadata)
  })
_sym_db.RegisterMessage(PartialObjectMetadata)

PartialObjectMetadataList = _reflection.GeneratedProtocolMessageType('PartialObjectMetadataList', (_message.Message,), {
  'DESCRIPTOR' : _PARTIALOBJECTMETADATALIST,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PartialObjectMetadataList)
  })
_sym_db.RegisterMessage(PartialObjectMetadataList)

Patch = _reflection.GeneratedProtocolMessageType('Patch', (_message.Message,), {
  'DESCRIPTOR' : _PATCH,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Patch)
  })
_sym_db.RegisterMessage(Patch)

PatchOptions = _reflection.GeneratedProtocolMessageType('PatchOptions', (_message.Message,), {
  'DESCRIPTOR' : _PATCHOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.PatchOptions)
  })
_sym_db.RegisterMessage(PatchOptions)

Preconditions = _reflection.GeneratedProtocolMessageType('Preconditions', (_message.Message,), {
  'DESCRIPTOR' : _PRECONDITIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Preconditions)
  })
_sym_db.RegisterMessage(Preconditions)

RootPaths = _reflection.GeneratedProtocolMessageType('RootPaths', (_message.Message,), {
  'DESCRIPTOR' : _ROOTPATHS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.RootPaths)
  })
_sym_db.RegisterMessage(RootPaths)

ServerAddressByClientCIDR = _reflection.GeneratedProtocolMessageType('ServerAddressByClientCIDR', (_message.Message,), {
  'DESCRIPTOR' : _SERVERADDRESSBYCLIENTCIDR,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR)
  })
_sym_db.RegisterMessage(ServerAddressByClientCIDR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Status)
  })
_sym_db.RegisterMessage(Status)

StatusCause = _reflection.GeneratedProtocolMessageType('StatusCause', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCAUSE,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.StatusCause)
  })
_sym_db.RegisterMessage(StatusCause)

StatusDetails = _reflection.GeneratedProtocolMessageType('StatusDetails', (_message.Message,), {
  'DESCRIPTOR' : _STATUSDETAILS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.StatusDetails)
  })
_sym_db.RegisterMessage(StatusDetails)

TableOptions = _reflection.GeneratedProtocolMessageType('TableOptions', (_message.Message,), {
  'DESCRIPTOR' : _TABLEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.TableOptions)
  })
_sym_db.RegisterMessage(TableOptions)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Time)
  })
_sym_db.RegisterMessage(Time)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMP,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Timestamp)
  })
_sym_db.RegisterMessage(Timestamp)

TypeMeta = _reflection.GeneratedProtocolMessageType('TypeMeta', (_message.Message,), {
  'DESCRIPTOR' : _TYPEMETA,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.TypeMeta)
  })
_sym_db.RegisterMessage(TypeMeta)

UpdateOptions = _reflection.GeneratedProtocolMessageType('UpdateOptions', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOPTIONS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.UpdateOptions)
  })
_sym_db.RegisterMessage(UpdateOptions)

Verbs = _reflection.GeneratedProtocolMessageType('Verbs', (_message.Message,), {
  'DESCRIPTOR' : _VERBS,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.Verbs)
  })
_sym_db.RegisterMessage(Verbs)

WatchEvent = _reflection.GeneratedProtocolMessageType('WatchEvent', (_message.Message,), {
  'DESCRIPTOR' : _WATCHEVENT,
  '__module__' : 'k8s.io.apimachinery.pkg.apis.meta.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.apis.meta.v1.WatchEvent)
  })
_sym_db.RegisterMessage(WatchEvent)


DESCRIPTOR._options = None
_LABELSELECTOR_MATCHLABELSENTRY._options = None
_OBJECTMETA_LABELSENTRY._options = None
_OBJECTMETA_ANNOTATIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)
